git_cmd

Function git_cmd 

pub fn git_cmd() -> Command
Create a Command for git with process-environment isolation.

Strips GIT_DIR and GIT_WORK_TREE so that inherited environment variables cannot override the explicit -C path used by all functions in this crate.