git_cmd

Function git_cmd 

pub fn git_cmd() -> Command
Create a Command for git with process-environment isolation.

Strips repo, worktree, index, object-store, discovery, and execution helper overrides so inherited environment variables cannot bypass the explicit -C path used by functions in this crate or launch ambient helper programs.